@@ -1,7 +1,7 @@
 use std::process::Command;
 
 fn main() {
-    println!("cargo:rerun-if-changed=template/scripts/app.ts");
+    // println!("cargo:rerun-if-changed=template/scripts/app.ts");
 
     Command::new("tsc")
         .spawn()
