@@ -7,7 +7,7 @@ use env_logger;
 use handlebars::Handlebars;
 
 use crate::api::Client;
-use crate::db::connect;
+use crate::db;
 use crate::project::Project;
 use crate::server::routes::{api, dashboard, entity, models};
 use crate::template;
@@ -21,7 +21,7 @@ pub struct AppContext {
 
 #[actix_rt::main]
 pub async fn start_server(root: String) -> Result<()> {
-    dotenv::from_path(format!("{}/.env", &root)).ok();
+    dotenv::from_path(format!("{}/.env", &root))?;
     println!("Starting server...");
 
     let host = "127.0.0.1";
@@ -35,7 +35,10 @@ pub async fn start_server(root: String) -> Result<()> {
     let project = Project::from_dir(&root)?;
 
     println!("Connecting to the database...");
-    let db = connect(project.db_uri.as_str()).await?.database("mezzo");
+    let db = db::connect(project.db_uri.as_str())
+        .await?
+        .database("mezzo");
+
     let client = Client::new(db);
 
     let server = HttpServer::new(move || {
