@@ -1,6 +1,6 @@
 use actix_web::{get, web, HttpResponse, Responder};
 use serde_json::json;
-use std::fs::read_to_string;
+use std::fs;
 
 use crate::server::{utils::render::render_page, AppContext};
 
@@ -26,7 +26,7 @@ pub async fn static_file(
         false => "text",
     };
 
-    match read_to_string(format!("{}/public/{}", context.root, filename).as_str()) {
+    match fs::read_to_string(format!("{}/.mezzo/public/{}", context.root, filename).as_str()) {
         Ok(html) => HttpResponse::Ok()
             .body(html)
             .with_header("Content-Type", mime),
