@@ -1,6 +1,7 @@
 use std::sync::Arc;
 
-use crate::{model::Model, server::AppContext};
+use crate::model::Model;
+use crate::server::AppContext;
 
 pub fn get_model(ctx: Arc<AppContext>, name: String) -> Option<Model> {
     ctx.project
